searchData={"items":[{"type":"module","title":"Usher.Invitations.CreateInvitation","doc":"Creates a new invitation with a token and default expiration datetime.","ref":"Usher.Invitations.CreateInvitation.html"},{"type":"function","title":"Usher.Invitations.CreateInvitation.call/1","doc":"","ref":"Usher.Invitations.CreateInvitation.html#call/1"},{"type":"module","title":"Usher.Migration","doc":"Migration helpers for creating Usher tables.\n\nUse this module in your application's migrations to create the necessary\ndatabase tables for Usher.","ref":"Usher.Migration.html"},{"type":"function","title":"Usher.Migration.create_usher_invitations_table/1","doc":"Creates the usher_invitations table.","ref":"Usher.Migration.html#create_usher_invitations_table/1"},{"type":"function","title":"Usage - Usher.Migration.create_usher_invitations_table/1","doc":"In your migration file:\n\n    defmodule MyApp.Repo.Migrations.CreateUsherInvitations do\n      use Ecto.Migration\n      import Usher.Migration\n\n      def change do\n        create_usher_invitations_table()\n      end\n    end","ref":"Usher.Migration.html#create_usher_invitations_table/1-usage"},{"type":"function","title":"Options - Usher.Migration.create_usher_invitations_table/1","doc":"* `:table_name` - Custom table name (defaults to configured table name)\n  * `:prefix` - Schema prefix for the table","ref":"Usher.Migration.html#create_usher_invitations_table/1-options"},{"type":"function","title":"Examples - Usher.Migration.create_usher_invitations_table/1","doc":"# Default table name\n    create_usher_invitations_table()\n\n    # Custom table name\n    create_usher_invitations_table(table_name: \"my_invitations\")\n\n    # With schema prefix\n    create_usher_invitations_table(prefix: \"usher\")","ref":"Usher.Migration.html#create_usher_invitations_table/1-examples"},{"type":"function","title":"Usher.Migration.drop_usher_invitations_table/1","doc":"Drops the usher_invitations table.","ref":"Usher.Migration.html#drop_usher_invitations_table/1"},{"type":"function","title":"Usage - Usher.Migration.drop_usher_invitations_table/1","doc":"drop_usher_invitations_table()","ref":"Usher.Migration.html#drop_usher_invitations_table/1-usage"},{"type":"function","title":"Options - Usher.Migration.drop_usher_invitations_table/1","doc":"* `:table_name` - Custom table name (defaults to configured table name)","ref":"Usher.Migration.html#drop_usher_invitations_table/1-options"},{"type":"function","title":"Examples - Usher.Migration.drop_usher_invitations_table/1","doc":"# Default table name\n    drop_usher_invitations_table()\n\n    # Custom table name\n    drop_usher_invitations_table(table_name: \"my_invitations\")","ref":"Usher.Migration.html#drop_usher_invitations_table/1-examples"},{"type":"module","title":"Usher","doc":"Usher is a web framework-agnostic invitation link management library for\nany Elixir application with Ecto.","ref":"Usher.html"},{"type":"module","title":"Getting Started - Usher","doc":"To use Usher in your application, you need to:\n\n1. Run the migrations\n2. Configure Usher with your repo\n3. Use the functions provided to manage invitations","ref":"Usher.html#module-getting-started"},{"type":"module","title":"Database Setup - Usher","doc":"Generate and run the migration:\n\n    mix ecto.gen.migration create_usher_tables\n\nThen add the Usher schema to your migration:\n\n    defmodule MyApp.Repo.Migrations.CreateUsherTables do\n      use Ecto.Migration\n\n      def change do\n        Usher.Migration.create_usher_invitations_table()\n      end\n    end","ref":"Usher.html#module-database-setup"},{"type":"module","title":"Configuration - Usher","doc":"In your `config/config.exs` (or whichever environment you prefer),\nset up the Usher configuration:\n\n    config :usher,\n      repo: MyApp.Repo,\n      token_length: 16,\n      default_expires_in: {7, :days}\n      table_name: \"myapp_invitations\"\n\nAll the values above have defaults, which you can find in `Usher.Config`.","ref":"Usher.html#module-configuration"},{"type":"module","title":"Basic Usage - Usher","doc":"# Create an invitation\n    {:ok, invitation} = Usher.create_invitation()\n\n    # Get invitation by token\n    invitation = Usher.get_invitation_by_token(\"abc123\")\n\n    # Validate and consume invitation\n    case Usher.validate_invitation_token(\"abc123\") do\n      {:ok, invitation} ->\n        # Proceed with registration\n        Usher.increment_joined_count(invitation)\n      {:error, :invalid_token} ->\n        # Handle invalid token\n      {:error, :expired} ->\n        # Handle expired token\n    end","ref":"Usher.html#module-basic-usage"},{"type":"module","title":"Features - Usher","doc":"- Token generation using cryptographic functions\n- Configurable token length and expiration periods\n- Framework-agnostic design works with any Ecto-based application","ref":"Usher.html#module-features"},{"type":"function","title":"Usher.change_invitation/2","doc":"Returns an `%Ecto.Changeset{}` for tracking invitation changes.","ref":"Usher.html#change_invitation/2"},{"type":"function","title":"Examples - Usher.change_invitation/2","doc":"iex> Usher.change_invitation(invitation)\n    %Ecto.Changeset{data: %Usher.Invitation{}}","ref":"Usher.html#change_invitation/2-examples"},{"type":"function","title":"Usher.create_invitation/1","doc":"Creates a new invitation with a token and default expiration datetime.","ref":"Usher.html#create_invitation/1"},{"type":"function","title":"Options - Usher.create_invitation/1","doc":"* `:expires_at` - Custom expiration datetime (overrides default)\n  * `:token` - Custom token (overrides generated token)","ref":"Usher.html#create_invitation/1-options"},{"type":"function","title":"Examples - Usher.create_invitation/1","doc":"iex> Usher.create_invitation()\n    {:ok, %Usher.Invitation{token: \"abc123...\", expires_at: ~U[...]}}\n\n    iex> Usher.create_invitation(expires_at: ~U[2024-12-31 23:59:59Z])\n    {:ok, %Usher.Invitation{expires_at: ~U[2024-12-31 23:59:59Z]}}","ref":"Usher.html#create_invitation/1-examples"},{"type":"function","title":"Usher.delete_invitation/1","doc":"Deletes an invitation.","ref":"Usher.html#delete_invitation/1"},{"type":"function","title":"Examples - Usher.delete_invitation/1","doc":"iex> Usher.delete_invitation(invitation)\n    {:ok, %Usher.Invitation{}}\n\n    iex> Usher.delete_invitation(bad_invitation)\n    {:error, %Ecto.Changeset{}}","ref":"Usher.html#delete_invitation/1-examples"},{"type":"function","title":"Usher.get_invitation!/1","doc":"Gets a single invitation by ID. Raises if not found.","ref":"Usher.html#get_invitation!/1"},{"type":"function","title":"Examples - Usher.get_invitation!/1","doc":"iex> Usher.get_invitation!(id)\n    %Usher.Invitation{}\n\n    iex> Usher.get_invitation!(\"nonexistent\")\n    ** (Ecto.NoResultsError)","ref":"Usher.html#get_invitation!/1-examples"},{"type":"function","title":"Usher.get_invitation_by_token/1","doc":"Gets an invitation by token.","ref":"Usher.html#get_invitation_by_token/1"},{"type":"function","title":"Examples - Usher.get_invitation_by_token/1","doc":"iex> Usher.get_invitation_by_token(\"valid_token\")\n    %Usher.Invitation{}\n\n    iex> Usher.get_invitation_by_token(\"invalid\")\n    nil","ref":"Usher.html#get_invitation_by_token/1-examples"},{"type":"function","title":"Usher.increment_joined_count/1","doc":"Increments the joined count for an invitation.\n\nThis is typically called when a user successfully registers using the invitation.","ref":"Usher.html#increment_joined_count/1"},{"type":"function","title":"Examples - Usher.increment_joined_count/1","doc":"iex> Usher.increment_joined_count(invitation)\n    {:ok, %Usher.Invitation{joined_count: 1}}","ref":"Usher.html#increment_joined_count/1-examples"},{"type":"function","title":"Usher.invitation_url/2","doc":"Builds an invitation URL for the given token and base URL.","ref":"Usher.html#invitation_url/2"},{"type":"function","title":"Examples - Usher.invitation_url/2","doc":"iex> Usher.invitation_url(\"abc123\", \"https://example.com/signup\")\n    \"https://example.com/signup?invitation_token=abc123\"","ref":"Usher.html#invitation_url/2-examples"},{"type":"function","title":"Usher.list_invitations/0","doc":"Retrieves all invitations.","ref":"Usher.html#list_invitations/0"},{"type":"function","title":"Examples - Usher.list_invitations/0","doc":"iex> Usher.list_invitations()\n    [%Usher.Invitation{}, ...]","ref":"Usher.html#list_invitations/0-examples"},{"type":"function","title":"Usher.validate_invitation_token/1","doc":"Validates an invitation token exists and returns the invitation if valid.\n\nReturns `{:ok, invitation}` if the token exists and hasn't expired.\nReturns `{:error, reason}` if the token is invalid or expired.","ref":"Usher.html#validate_invitation_token/1"},{"type":"function","title":"Examples - Usher.validate_invitation_token/1","doc":"iex> Usher.validate_invitation_token(\"valid_token\")\n    {:ok, %Usher.Invitation{}}\n\n    iex> Usher.validate_invitation_token(\"expired_token\")\n    {:error, :invitation_expired}\n\n    iex> Usher.validate_invitation_token(\"invalid_token\")\n    {:error, :invalid_token}","ref":"Usher.html#validate_invitation_token/1-examples"},{"type":"module","title":"Usher.Config","doc":"Configuration management for Usher.\n\nHandles loading and validating configuration from the application environment.","ref":"Usher.Config.html"},{"type":"function","title":"Usher.Config.all/0","doc":"Returns all Usher configuration as a keyword list.\n\nUseful for debugging or displaying current configuration.","ref":"Usher.Config.html#all/0"},{"type":"function","title":"Examples - Usher.Config.all/0","doc":"iex> Usher.Config.all()\n    [\n      repo: MyApp.Repo,\n      token_length: 16,\n      default_expires_in: {7, :day},\n      table_name: \"usher_invitations\"\n    ]","ref":"Usher.Config.html#all/0-examples"},{"type":"function","title":"Usher.Config.default_expires_in/0","doc":"Returns the configured default expiration duration.\n\nAccepts a `Duration.unit_pair()`, such as `{30, :minute}`.\n[See the docs for Duration](https://hexdocs.pm/duration/Duration.html#unit_pair/0).\n\nDefaults to 7 days if not configured.","ref":"Usher.Config.html#default_expires_in/0"},{"type":"function","title":"Usher.Config.repo/0","doc":"Returns the configured Ecto repository.\n\nThis is required for Usher to function and must be set in your application config:\n\n    config :usher, repo: MyApp.Repo\n\nRaises if not configured.","ref":"Usher.Config.html#repo/0"},{"type":"function","title":"Usher.Config.table_name/0","doc":"Returns the configured table name for invitations.\n\nDefaults to \"usher_invitations\" if not configured.","ref":"Usher.Config.html#table_name/0"},{"type":"function","title":"Examples - Usher.Config.table_name/0","doc":"# Default\n    iex> Usher.Config.table_name()\n    \"usher_invitations\"\n\n    # Configured\n    config :usher, table_name: \"my_invitations\"\n    iex> Usher.Config.table_name()\n    \"my_invitations\"","ref":"Usher.Config.html#table_name/0-examples"},{"type":"function","title":"Usher.Config.token_length/0","doc":"Returns the configured token length.\n\nDefaults to 16 characters if not configured.","ref":"Usher.Config.html#token_length/0"},{"type":"module","title":"Usher.Invitation","doc":"Invitation schema for Usher.\n\nRepresents an invitation with a unique token, expiration date, and usage tracking.","ref":"Usher.Invitation.html"},{"type":"function","title":"Usher.Invitation.changeset/2","doc":"Changeset for creating and updating invitations.","ref":"Usher.Invitation.html#changeset/2"},{"type":"function","title":"Examples - Usher.Invitation.changeset/2","doc":"iex> Usher.Invitation.changeset(%Usher.Invitation{}, %{\n    ...>   token: \"abc123\",\n    ...>   expires_at: ~U[2024-12-31 23:59:59Z]\n    ...> })\n    %Ecto.Changeset{valid?: true}\n\n    iex> Usher.Invitation.changeset(%Usher.Invitation{}, %{})\n    %Ecto.Changeset{valid?: false, errors: [token: {\"can't be blank\", _}]}","ref":"Usher.Invitation.html#changeset/2-examples"},{"type":"function","title":"Usher.Invitation.increment_joined_count_changeset/1","doc":"Changeset for incrementing the joined count.\n\nThis is for when a user successfully registers using the invitation.","ref":"Usher.Invitation.html#increment_joined_count_changeset/1"},{"type":"function","title":"Examples - Usher.Invitation.increment_joined_count_changeset/1","doc":"iex> invitation = %Usher.Invitation{joined_count: 0}\n    iex> Usher.Invitation.increment_joined_count_changeset(invitation)\n    %Ecto.Changeset{changes: %{joined_count: 1}}","ref":"Usher.Invitation.html#increment_joined_count_changeset/1-examples"},{"type":"type","title":"Usher.Invitation.t/0","doc":"","ref":"Usher.Invitation.html#t:t/0"},{"type":"extras","title":"Usher","doc":"# Usher\n \n   \n     \n   \n   \n     \n   \n   \n     \n   \n \n\nUsher is a web framework-agnostic invitation link management library for any Elixir application with Ecto.\n\n>🚧 This library is in its infancy so you should treat all versions as early pre-release versions. We'll make the best effort to give heads up about breaking changes; however we can't guarantee backwards compatibility for every change.","ref":"readme.html"},{"type":"extras","title":"Current Features - Usher","doc":"- 🔐 **Token generation** using cryptographic functions\n- 🏗️ **Framework agnostic** - works with any Ecto-based application","ref":"readme.html#current-features"},{"type":"extras","title":"What's planned? - Usher","doc":"- [ ] Auto-cleanup of expired invitations.\n- [ ] More advanced usage tracking.\n   - [ ] Metadata about those who visited and used the invitation (approx. location, user agent, etc.).\n   - [ ] Linking invitation tokens to user accounts (e.g. to track which user registered with which invitation).\n- [ ] Invitation expiration after X number of uses (including one-time use links).\n- [ ] One-time use invitation links tied to specific email addresses.\n- [ ] Descriptions for invitation links so you can provide context for its usage.","ref":"readme.html#what-s-planned"},{"type":"extras","title":"Installation - Usher","doc":"Add `usher` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:usher, \"~> 0.1.0\"}\n  ]\nend\n```\n\nUsher requires Elixir 1.14 or later, and OTP 25 or later. It may work with earlier versions, but it wasn't tested against them.","ref":"readme.html#installation"},{"type":"extras","title":"Setup - Usher","doc":"","ref":"readme.html#setup"},{"type":"extras","title":"1. Database Migration - Usher","doc":"Generate and run the migration to create the invitations table:\n```bash\nmix ecto.gen.migration create_usher_tables\n```\n\nAdd the Usher schema to your migration:\n```elixir\ndefmodule MyApp.Repo.Migrations.CreateUsherTables do\n  use Ecto.Migration\n\n  def change do\n    Usher.Migration.create_usher_invitations_table()\n  end\nend\n```\n\nRun the migration:\n```bash\nmix ecto.migrate\n```","ref":"readme.html#1-database-migration"},{"type":"extras","title":"2. Configuration - Usher","doc":"Configure Usher in your `config/config.exs`:\n```elixir\nconfig :usher,\n  repo: MyApp.Repo,\n  token_length: 16,\n  default_expires_in: {7, :day},\n  table_name: \"usher_invitations\"\n```\n\nAll the values above have defaults, which you can find in `Usher.Config`.","ref":"readme.html#2-configuration"},{"type":"extras","title":"Basic Usage - Usher","doc":"","ref":"readme.html#basic-usage"},{"type":"extras","title":"Creating Invitations - Usher","doc":"```elixir\n# Create with defaults (7-day expiration, generated token)\n{:ok, invitation} = Usher.create_invitation()\n\n# Create with custom expiration\n{:ok, invitation} = Usher.create_invitation(%{\n  expires_at: DateTime.add(DateTime.utc_now(), 30, :day)\n})\n\n# Create with custom token\n{:ok, invitation} = Usher.create_invitation(%{\n  token: \"custom-invite-token\"\n})\n```","ref":"readme.html#creating-invitations"},{"type":"extras","title":"Validating Invitations - Usher","doc":"```elixir\ncase Usher.validate_invitation_token(\"abc123\") do\n  {:ok, invitation} -> \n    # Valid invitation - proceed with registration\n    IO.puts(\"Welcome! Invitation expires: #{invitation.expires_at}\")\n    \n  {:error, :invalid_token} -> \n    # Token doesn't exist\n    IO.puts(\"Invalid invitation token\")\n    \n  {:error, :expired} -> \n    # Token exists but expired\n    IO.puts(\"This invitation has expired\")\nend\n```","ref":"readme.html#validating-invitations"},{"type":"extras","title":"Tracking Usage - Usher","doc":"```elixir\n# When a user successfully registers with an invitation\n{:ok, updated_invitation} = Usher.increment_joined_count(invitation)\nIO.puts(\"#{updated_invitation.joined_count} users have used this invitation\")\n```","ref":"readme.html#tracking-usage"},{"type":"extras","title":"Building Invitation URLs - Usher","doc":"```elixir\n# Simple URL\nurl = Usher.invitation_url(\"abc123\", \"https://myapp.com/signup\")\n# => \"https://myapp.com/signup?invitation_token=abc123\"\n```","ref":"readme.html#building-invitation-urls"},{"type":"extras","title":"Cleaning Up Expired Invitations - Usher","doc":"While this feature doesn't exist for the library yet, you can periodically clean up expired invitations using one of the following examples:\n```elixir\ndefmodule MyApp.InvitationCleanup do\n  @moduledoc \"\"\"\n  A module for cleaning up expired invitations.\n  \n  This can be used with a job scheduler like Oban or simply a GenServer\n  to periodically remove expired invitations from the database.\n  \"\"\"\n  \n  @doc \"\"\"\n  Removes expired invitations older than the given number of days.\n  \n  This is useful if you want to keep recently expired invitations\n  for debugging or analytics purposes.\n  \"\"\"\n  def cleanup_old_expired_invitations(days_old \\\\ 30) do\n    cutoff_date = DateTime.utc_now() |> DateTime.add(-days_old, :day)\n    \n    old_expired_invitations = \n      Usher.list_invitations()\n      |> Enum.filter(fn invitation ->\n        DateTime.compare(invitation.expires_at, cutoff_date) == :lt\n      end)\n    \n    deleted_count = \n      old_expired_invitations\n      |> Enum.reduce(0, fn invitation, acc ->\n        # Alternatively, you can use your application's repo to\n        # `Repo.delete_all/2` expired invitations in bulk.\n        case Usher.delete_invitation(invitation) do\n          {:ok, _} -> acc + 1\n          {:error, _} -> acc\n        end\n      end)\n    \n    deleted_count\n  end\nend\n```\n\nYou can then use this module in various ways:\n**With Oban (easiest):**\n```elixir\ndefmodule MyApp.Workers.InvitationCleanupWorker do\n  @moduledoc \"\"\"\n  A worker that periodically cleans up old expired invitations.\n\n  This worker can be scheduled to run periodically with Oban Cron.\n  \"\"\"\n  use Oban.Worker, queue: :cleanup\n\n  @impl Oban.Worker\n  def perform(%Oban.Job{}) do\n    deleted_count = MyApp.InvitationCleanup.cleanup_old_expired_invitations(7)\n\n    {:ok, deleted_count}\n  end\nend\n```\n\n**With a GenServer:**\n```elixir\ndefmodule MyApp.InvitationCleanupCron do\n  @moduledoc \"\"\"\n  A GenServer that periodically cleans up expired invitations.\n  \n  Runs cleanup tasks at configurable intervals and can be\n  added to your application's supervision tree.\n  \"\"\"\n  use GenServer\n  \n  require Logger\n\n  # Default cleanup interval: 24 hours\n  @default_cleanup_interval_ms 24 * 60 * 60 * 1000\n  @default_days_old 7\n\n  def start_link(opts \\\\ []) do\n    GenServer.start_link(__MODULE__, opts, name: __MODULE__)\n  end\n  \n  @impl GenServer\n  def init(opts) do\n    cleanup_interval = Keyword.get(opts, :cleanup_interval_ms, @default_cleanup_interval_ms)\n    days_old = Keyword.get(opts, :days_old, @default_days_old)\n\n    schedule_cleanup(cleanup_interval)\n    \n    state = %{\n      cleanup_interval: cleanup_interval,\n      days_old: days_old,\n      last_cleanup: nil\n    }\n    \n    Logger.info(\"InvitationCleanupCron started with #{cleanup_interval}ms interval\")\n    {:ok, state}\n  end\n  \n  @impl GenServer\n  def handle_info(:cleanup, state) do\n    deleted_count = MyApp.InvitationCleanup.cleanup_old_expired_invitations(state.days_old)\n    \n    new_state = %{\n      state | \n      last_cleanup: DateTime.utc_now()\n    }\n    \n    Logger.info(\"Cleanup completed. Deleted #{deleted_count} invitations. Total cleanups: #{new_state.cleanup_count}\")\n    \n    # Schedule the next cleanup\n    schedule_cleanup(state.cleanup_interval)\n    \n    {:noreply, new_state}\n  end\n  \n  defp schedule_cleanup(interval) do\n    Process.send_after(self(), :cleanup, interval)\n  end\nend\n```\n\nThen add it to your application's supervision tree:\n```elixir\ndefmodule MyApp.Application do\n  use Application\n  \n  def start(_type, _args) do\n    children = [\n      # ... other children\n      {MyApp.InvitationCleanupCron, [\n        cleanup_interval_ms: 2 * 60 * 60 * 1000,  # 2 hours\n        days_old: 14  # Delete invitations expired more than 14 days ago\n      ]}\n    ]\n    \n    opts = [strategy: :one_for_one, name: MyApp.Supervisor]\n    Supervisor.start_link(children, opts)\n  end\nend\n```\n\n**Manual cleanup:**\n```elixir\niex> MyApp.InvitationCleanup.cleanup_old_expired_invitations(7)\nCleaned up 3 old expired invitations (older than 7 days)\n3\n```","ref":"readme.html#cleaning-up-expired-invitations"},{"type":"extras","title":"Phoenix Integration - Usher","doc":"You can use Usher with Phoenix. Here's how you might go about doing so:","ref":"readme.html#phoenix-integration"},{"type":"extras","title":"Controller Integration - Usher","doc":"Inside a controller:\n```elixir\ndefmodule MyAppWeb.UserRegistrationController do\n  use MyAppWeb, :controller\n  \n  def new(conn, params) do\n    case validate_invitation_from_params(params) do\n      {:ok, invitation} ->\n        conn\n        |> assign(:invitation, invitation)\n        |> render(:new)\n        \n      {:error, reason} ->\n        message = invitation_error_message(reason)\n        conn\n        |> put_flash(:error, message)\n        |> redirect(to: ~p\"/\")\n    end\n  end\n  \n  def create(conn, %{\"user\" => user_params} = params) do\n    case validate_invitation_from_params(params) do\n      {:ok, invitation} ->\n        # Create user and increment invitation count\n        MyApp.Repo.transaction(fn ->\n          with {:ok, user} <- create_user(user_params),\n              {:ok, _} <- Usher.increment_joined_count(invitation) do\n            conn\n            |> put_flash(:info, \"Account created successfully!\")\n            |> redirect(to: ~p\"/dashboard\")\n          end\n        end)\n        \n      {:error, reason} ->\n        # This is a function that you can define,\n        # e.g. in the fallback controller.\n        handle_invitation_error(conn, reason)\n    end\n  end\n  \n  defp validate_invitation_from_params(params) do\n    case params[\"invitation_token\"] do\n      token when is_binary(token) ->\n        Usher.validate_invitation_token(token)\n      \n      _ ->\n        {:error, :missing_token}\n    end\n  end\n  \n  defp invitation_error_message(:missing_token) do\n    \"An invitation is required to join. Please contact us for an invitation.\"\n  end\n  \n  defp invitation_error_message(:invalid_token) do\n    \"This invitation link is invalid. Please check the link and try again.\"\n  end\n  \n  defp invitation_error_message(:invitation_expired) do\n    \"This invitation has expired. Please request a new invitation.\"\n  end\n  \n  defp invitation_error_message(_unknown) do\n    \"There was a problem with your invitation. Please try again or contact support.\"\n  end\nend\n```","ref":"readme.html#controller-integration"},{"type":"extras","title":"LiveView Integration - Usher","doc":"Inside a LiveView:\n```elixir\ndefmodule MyAppWeb.RegistrationLive do\n  use MyAppWeb, :live_view\n\n  def mount(params, _session, socket) do\n    case validate_invitation_from_params(params) do\n      {:ok, invitation} ->\n        {:ok, assign(socket, :invitation, invitation)}\n        \n      {:error, reason} ->\n        message = invitation_error_message(reason)\n        {:ok, \n         socket\n         |> put_flash(:error, message)\n         |> redirect(to: ~p\"/\")}\n    end\n  end\n  \n  defp validate_invitation_from_params(params) do\n    case params[\"invitation_token\"] do\n      token when is_binary(token) ->\n        Usher.validate_invitation_token(token)\n      \n      _ ->\n        {:error, :missing_token}\n    end\n  end\n  \n  defp invitation_error_message(:missing_token) do\n    \"An invitation is required to join. Please contact us for an invitation.\"\n  end\n  \n  defp invitation_error_message(:invalid_token) do\n    \"This invitation link is invalid. Please check the link and try again.\"\n  end\n  \n  defp invitation_error_message(:invitation_expired) do\n    \"This invitation has expired. Please request a new invitation.\"\n  end\n  \n  defp invitation_error_message(_unknown) do\n    \"There was a problem with your invitation. Please try again or contact support.\"\n  end\nend\n```","ref":"readme.html#liveview-integration"},{"type":"extras","title":"Creating Your Own Phoenix Plug - Usher","doc":"If you want to create a custom plug for invitations, here's an example implementation you can use:\n```elixir\ndefmodule MyApp.InvitationPlug do\n  import Phoenix.Controller, only: [put_flash: 3, redirect: 2]\n  import Plug.Conn\n\n  @behaviour Plug\n\n  def init(opts), do: opts\n\n  def call(conn, opts) do\n    redirect_on_error_to = Keyword.get(opts, :redirect_on_error_to, \"/\")\n    flash_key = Keyword.fetch!(opts, :flash_key)\n\n    case validate_invitation_from_params(conn.params) do\n      {:ok, invitation} ->\n        conn\n        |> assign(:invitation, invitation)\n        # If you don't need to invitation token for the entire session,\n        # you can use `assign/3` instead.\n        |> put_invitation_token_in_session(invitation.token)\n\n      {:error, reason} ->\n        message = invitation_error_message(reason)\n\n        conn\n        |> put_flash(flash_key, message)\n        |> redirect(to: redirect_on_error_to)\n        |> halt()\n    end\n  end\n\n  def put_invitation_token_in_session(conn, token) do\n    put_session(conn, :invitation_token, token)\n  end\n\n  def get_invitation_token_from_session(conn) do\n    get_session(conn, :invitation_token)\n  end\n\n  def validate_invitation_from_session(conn) do\n    case get_invitation_token_from_session(conn) do\n      token when is_binary(token) ->\n        Usher.validate_invitation_token(token)\n\n      _ ->\n        {:error, :missing_token}\n    end\n  end\n\n  defp validate_invitation_from_params(params) do\n    case params[\"invitation_token\"] do\n      token when is_binary(token) ->\n        Usher.validate_invitation_token(token)\n\n      _ ->\n        {:error, :missing_token}\n    end\n  end\n\n  defp invitation_error_message(:missing_token) do\n    \"An invitation is required to join. Please contact us for an invitation.\"\n  end\n\n  defp invitation_error_message(:invalid_token) do\n    \"This invitation link is invalid. Please check the link and try again.\"\n  end\n\n  defp invitation_error_message(:expired) do\n    \"This invitation has expired. Please request a new invitation.\"\n  end\n\n  defp invitation_error_message(_unknown) do\n    \"There was a problem with your invitation. Please try again or contact support.\"\n  end\nend\n```\n\nYou can then use this plug in your router:\n```elixir\npipeline :invitation_required do\n  plug MyApp.InvitationPlug, redirect_on_error_to: \"/contact\"\nend\n\nscope \"/signup\" do\n  pipe_through [:browser, :invitation_required]\n  get \"/\", UserRegistrationController, :new\n  post \"/\", UserRegistrationController, :create\nend\n```","ref":"readme.html#creating-your-own-phoenix-plug"},{"type":"extras","title":"Configuration Options - Usher","doc":"| Option | Default | Description |\n|--------|---------|-------------|\n| `:repo` | **Required** | Your Ecto repository module |\n| `:token_length` | `16` | Length of generated invitation tokens |\n| `:default_expires_in` | `{7, :day}` | Default expiration period for new invitations |\n| `:table_name` | `\"usher_invitations\"` | Database table name for invitations |","ref":"readme.html#configuration-options"},{"type":"extras","title":"Examples - Usher","doc":"","ref":"readme.html#examples"},{"type":"extras","title":"Checking invitations and creating a new one - Usher","doc":"```elixir\n# List all invitations\ninvitations = Usher.list_invitations()\n\n# Create invitation with custom expiration\n{:ok, invitation} = Usher.create_invitation(%{\n  expires_at: DateTime.add(DateTime.utc_now(), 1, :month)\n})\n\n# Build shareable URL\ninvite_url = Usher.invitation_url(invitation.token, \"https://myapp.com/signup\")\n```","ref":"readme.html#checking-invitations-and-creating-a-new-one"},{"type":"extras","title":"Contributing - Usher","doc":"1. Fork the repository\n2. Create your feature branch (`git checkout -b feature/amazing-feature`)\n3. Run tests (`mix test`)\n4. Commit your changes (`git commit -am 'Add amazing feature'`)\n5. Push to the branch (`git push origin feature/amazing-feature`)\n6. Open a Pull Request","ref":"readme.html#contributing"},{"type":"extras","title":"Testing - Usher","doc":"Usher requires PostgreSQL to be running, in order to execute its tests. You can either set up PostgreSQL or use the provided `docker-compose.yml` file. Run the tests with:\n```bash\nmix test\n```\n\nFor your own application tests, you can use the provided test fixtures:\n\n```elixir\n# In your test files\nimport Usher.TestFixtures\n\ntest \"user registration with invitation\" do\n  invitation = invitation_fixture()\n  # ... test your registration flow\nend\n```","ref":"readme.html#testing"},{"type":"extras","title":"License - Usher","doc":"This project is licensed under the MIT License - see the [LICENSE.md](LICENSE.md) file for details.","ref":"readme.html#license"},{"type":"extras","title":"Inspiration - Usher","doc":"We first built this invitation system into [Accomplish](https://github.com/typhoonworks/accomplish) and then decided to open-source it.","ref":"readme.html#inspiration"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}